package com.example.smartl

import androidx.compose.runtime.getValue
import androidx.compose.runtime.mutableStateOf
import androidx.compose.runtime.setValue
import androidx.lifecycle.ViewModel
import androidx.lifecycle.viewModelScope
import com.example.smartl.api.Repository
import com.example.smartl.api.Result.Success
import com.example.smartl.api.Result.Error
import kotlinx.coroutines.channels.Channel
import kotlinx.coroutines.flow.receiveAsFlow
import kotlinx.coroutines.launch

class ViewModelMain(private val repository: Repository): ViewModel() {
    private val _showErrorToastChannel = Channel<Boolean>()
    val showErrorToastChannel = _showErrorToastChannel.receiveAsFlow()
    var codeIsCorrect by mutableStateOf(false)

    fun sendCodeToEmail(email:String)
    {
        viewModelScope.launch {
            repository.sendCodeEmail(email).collect{
                when(it) {
                    is Error -> {
                        _showErrorToastChannel.send(true)
                    }
                    is Success -> {
                        _showErrorToastChannel.send(false)
                    }
                }
            }
        }
    }
    fun SignIn(email: String, code: String) {
        viewModelScope.launch {
            repository.signInCode(email, code).collect {
                when (it) {
                    is Error -> {
                        codeIsCorrect = false
                    }
                    is Success -> {
                        codeIsCorrect = true
                    }
                }
            }
        }
    }
}